.. _api_documentation:

API Reference
=============

.. toctree::
   :maxdepth: 1
   :glob:

   calc
   configuration
   context
   diffract
   engine
   geometries
   sample
   user
   util

.. toctree::
   :glob:
   :hidden:

   license
